OiRA

Help

1. Preparação
2. Envolvimento
3. Identificação + Avaliação
   1. 1 Commercial manned guarding
   2. Ω Riscos adicionados (por si)
      1. Ω.1 The entrance floor is often wet
   - Sem resposta
   - Adiado
   - OK
   - Atenção
4. Plano de Ação
5. Relatório
6. Estado 0%

No caso de considerar outros riscos não contidos na ferramenta, tem apossibilidade de adicioná-los agora:

Importante: Para não ter duplicaçao de riscos, recomendamos que primeiro explore os módulos predefinidos, se ainda não o fez.

Se não precisar de adicionar riscos, continue.

Anterior Continue para o plano de ação

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More